@@ -96,7 +96,7 @@ class AccountClient(BaseClient):
                           user_profile_image_file_id: str,
                           seller_status: str,
                           seller_status_reason: str,
-                          seller_account_balance: float) -> Any:
+                          seller_account_balance: float = None) -> Any:
         return self.put('user',
                         user_id=user_id,
                         user_email=user_email,
